@@ -6,10 +6,10 @@ import pandas
 
 
 def load_model(filename=None, data=None, solver=None, model_klass=None):
-    '''Load a test model and check it'''
+    """Load a test model and check it"""
     if data is None:
-        path = os.path.join(os.path.dirname(__file__), 'models')
-        with open(os.path.join(path, filename), 'r') as f:
+        path = os.path.join(os.path.dirname(__file__), "models")
+        with open(os.path.join(path, filename), "r") as f:
             data = f.read()
     else:
         path = None
@@ -31,7 +31,10 @@ def assert_model(model, expected_node_results):
             if isinstance(node, pywr.core.BaseNode):
                 assert_allclose(expected_node_results[node.name], node.flow, atol=1e-7)
             elif isinstance(node, pywr.core.Storage):
-                assert_allclose(expected_node_results[node.name], node.volume, atol=1e-7)
+                assert_allclose(
+                    expected_node_results[node.name], node.volume, atol=1e-7
+                )
+
 
 def build_timestep(model, date):
     dt = pandas.to_datetime(date)
