@@ -20,76 +20,92 @@ import pywr.parameters
 
 
 def test_run_simple1():
-    '''Test the most basic model possible'''
+    """Test the most basic model possible"""
     # parse the JSON into a model
-    model = load_model('simple1.json')
+    model = load_model("simple1.json")
 
     # run the model
     t0 = model.timestepper.start.to_pydatetime()
     model.step()
 
     # check results
-    demand1 = model.nodes['demand1']
+    demand1 = model.nodes["demand1"]
     assert_allclose(demand1.flow, 10.0, atol=1e-7)
     # initially the timestepper returns the first time-step, so timestepper.current
     # does not change after the first 'step'.
-    assert(model.timestepper.current.datetime - t0 == datetime.timedelta(0))
+    assert model.timestepper.current.datetime - t0 == datetime.timedelta(0)
     # check the timestamp incremented
     model.step()
-    assert(model.timestepper.current.datetime - t0 == datetime.timedelta(1))
+    assert model.timestepper.current.datetime - t0 == datetime.timedelta(1)
+
 
 def test_model_results():
-    '''Test model results object'''
+    """Test model results object"""
     import pywr
 
-    model = load_model('simple1.json')
+    model = load_model("simple1.json")
     res = model.run()
-    assert (isinstance(res, ModelResult))
-    assert (res.timesteps == 365)
-    assert (res.version == pywr.__version__)
-    assert res.solver_stats['number_of_cols']
-    assert res.solver_stats['number_of_rows']
+    assert isinstance(res, ModelResult)
+    assert res.timesteps == 365
+    assert res.version == pywr.__version__
+    assert res.solver_stats["number_of_cols"]
+    assert res.solver_stats["number_of_rows"]
     assert res.solver_name == model.solver.name
     print(res)
     print(res._repr_html_())
 
 
-@pytest.mark.parametrize("json_file", ['reservoir1.json', 'reservoir1_pc.json'])
+@pytest.mark.parametrize("json_file", ["reservoir1.json", "reservoir1_pc.json"])
 def test_run_reservoir1(json_file):
-    '''Test a reservoir with no refill
+    """Test a reservoir with no refill
 
     Without an additional supply the reservoir should empty and cause a failure.
-    '''
+    """
     model = load_model(json_file)
-    demand1 = model.nodes['demand1']
-    supply1 = model.nodes['supply1']
-    for demand, stored in [(10.0, 25.0), (10.0, 15.0), (10.0, 5.0), (5.0, 0.0), (0.0, 0.0)]:
+    demand1 = model.nodes["demand1"]
+    supply1 = model.nodes["supply1"]
+    for demand, stored in [
+        (10.0, 25.0),
+        (10.0, 15.0),
+        (10.0, 5.0),
+        (5.0, 0.0),
+        (0.0, 0.0),
+    ]:
         result = model.step()
         assert_allclose(demand1.flow, demand, atol=1e-7)
         assert_allclose(supply1.volume, stored, atol=1e-7)
 
 
 def test_run_reservoir2():
-    '''Test a reservoir fed by a river abstraction
+    """Test a reservoir fed by a river abstraction
 
     The river abstraction should refill the reservoir, but not quickly enough
     to keep up with the demand.
-    '''
-    model = load_model('reservoir2.json')
+    """
+    model = load_model("reservoir2.json")
 
-    demand1 = model.nodes['demand1']
-    supply1 = model.nodes['supply1']
-    catchment = model.nodes['catchment1']
-    assert(catchment.min_flow == 5)
-    for demand, stored in [(15.0, 25.0), (15.0, 15.0), (15.0, 5.0), (10.0, 0.0), (5.0, 0.0)]:
+    demand1 = model.nodes["demand1"]
+    supply1 = model.nodes["supply1"]
+    catchment = model.nodes["catchment1"]
+    assert catchment.min_flow == 5
+    for demand, stored in [
+        (15.0, 25.0),
+        (15.0, 15.0),
+        (15.0, 5.0),
+        (10.0, 0.0),
+        (5.0, 0.0),
+    ]:
         result = model.step()
         assert_allclose(demand1.flow[0], demand, atol=1e-7)
         assert_allclose(supply1.volume[0], stored, atol=1e-7)
 
+
 def test_empty_storage_min_flow():
 
     model = Model()
-    storage = Storage(model, "storage", initial_volume=100, max_volume=100, inputs=1, outputs=0)
+    storage = Storage(
+        model, "storage", initial_volume=100, max_volume=100, inputs=1, outputs=0
+    )
     otpt = Output(model, "output", min_flow=75)
     storage.connect(otpt)
     model.check()
@@ -97,38 +113,39 @@ def test_empty_storage_min_flow():
     with pytest.raises(RuntimeError):
         model.step()
 
+
 def test_run_river1():
-    '''Test a river abstraction with a simple catchment'''
-    model = load_model('river1.json')
+    """Test a river abstraction with a simple catchment"""
+    model = load_model("river1.json")
 
     result = model.step()
-    demand1 = model.nodes['demand1']
+    demand1 = model.nodes["demand1"]
     assert_allclose(demand1.flow, 5.0, atol=1e-7)
 
 
 def test_run_river2():
-    '''Test a river abstraction with two catchments, a confluence and a split'''
-    model = load_model('river2.json')
+    """Test a river abstraction with two catchments, a confluence and a split"""
+    model = load_model("river2.json")
 
     model.step()
 
-    demand1 = model.nodes['demand1']
+    demand1 = model.nodes["demand1"]
     assert_allclose(demand1.flow, 7.25, atol=1e-7)
-    demand2 = model.nodes['demand2']
+    demand2 = model.nodes["demand2"]
     assert_allclose(demand2.flow, 2.0, atol=1e-7)
 
 
 # Contains an out of range date for pandas.to_datetime
-@pytest.mark.parametrize("json_file", ['timeseries1.json', 'timeseries1_xlsx.json'])
+@pytest.mark.parametrize("json_file", ["timeseries1.json", "timeseries1_xlsx.json"])
 def test_run_timeseries1(json_file):
     model = load_model(json_file)
 
     # check first day initalised
-    assert(model.timestepper.start == datetime.datetime(2015, 1, 1))
+    assert model.timestepper.start == datetime.datetime(2015, 1, 1)
 
     # check results
-    demand1 = model.nodes['demand1']
-    catchment1 = model.nodes['catchment1']
+    demand1 = model.nodes["demand1"]
+    catchment1 = model.nodes["catchment1"]
     for expected in (23.92, 22.14, 22.57, 24.97, 27.59):
         result = model.step()
         assert_allclose(catchment1.flow, expected, atol=1e-7)
@@ -136,16 +153,18 @@ def test_run_timeseries1(json_file):
 
 
 # Contains an out of range date for pandas.to_datetime
-@pytest.mark.parametrize("json_file", ['timeseries1_weekly.json', 'timeseries1_weekly_hdf.json'])
+@pytest.mark.parametrize(
+    "json_file", ["timeseries1_weekly.json", "timeseries1_weekly_hdf.json"]
+)
 def test_run_timeseries1_weekly(json_file):
     model = load_model(json_file)
 
     # check first day initalised
-    assert(model.timestepper.start == datetime.datetime(2015, 1, 1))
+    assert model.timestepper.start == datetime.datetime(2015, 1, 1)
 
     # check results
-    demand1 = model.nodes['demand1']
-    catchment1 = model.nodes['catchment1']
+    demand1 = model.nodes["demand1"]
+    catchment1 = model.nodes["catchment1"]
     for expected in (23.92, 25.67, 28.24, 25.28, 21.84):
         result = model.step()
         assert_allclose(catchment1.flow, expected, atol=1e-7)
@@ -153,11 +172,11 @@ def test_run_timeseries1_weekly(json_file):
 
 
 def test_run_cost1():
-    model = load_model('cost1.json')
+    model = load_model("cost1.json")
 
-    supply1 = model.nodes['supply1']
-    supply2 = model.nodes['supply2']
-    demand1 = model.nodes['demand1']
+    supply1 = model.nodes["supply1"]
+    supply2 = model.nodes["supply2"]
+    demand1 = model.nodes["demand1"]
 
     assert_allclose(supply1.get_cost(None), 1)
     assert_allclose(supply2.get_cost(None), 2)  # more expensive
@@ -187,55 +206,64 @@ def test_run_cost1():
 
 
 def test_run_bottleneck():
-    '''Test max flow constraint on intermediate nodes is upheld'''
-    model = load_model('bottleneck.json')
+    """Test max flow constraint on intermediate nodes is upheld"""
+    model = load_model("bottleneck.json")
     result = model.step()
-    d1 = model.nodes['demand1']
-    d2 = model.nodes['demand2']
-    assert_allclose(d1.flow+d2.flow, 15.0, atol=1e-7)
+    d1 = model.nodes["demand1"]
+    d2 = model.nodes["demand2"]
+    assert_allclose(d1.flow + d2.flow, 15.0, atol=1e-7)
 
-@pytest.mark.skipif(Model().solver.name == "glpk-edge", reason="Not valid for GLPK Edge based solver.")
+
+@pytest.mark.skipif(
+    Model().solver.name == "glpk-edge", reason="Not valid for GLPK Edge based solver."
+)
 def test_run_discharge_upstream():
-    '''Test river with inline discharge (upstream)
+    """Test river with inline discharge (upstream)
 
     In this instance the discharge is upstream of the abstraction, and so can
     be abstracted in the same way as the water from the catchment
-    '''
-    model = load_model('river_discharge1.json')
+    """
+    model = load_model("river_discharge1.json")
     model.step()
-    demand = model.nodes['demand1']
-    term = model.nodes['term1']
+    demand = model.nodes["demand1"]
+    term = model.nodes["term1"]
     assert_allclose(demand.flow, 8.0, atol=1e-7)
     assert_allclose(term.flow, 0.0, atol=1e-7)
 
-@pytest.mark.skipif(Model().solver.name == "glpk-edge", reason="Not valid for GLPK Edge based solver.")
+
+@pytest.mark.skipif(
+    Model().solver.name == "glpk-edge", reason="Not valid for GLPK Edge based solver."
+)
 def test_run_discharge_downstream():
-    '''Test river with inline discharge (downstream)
+    """Test river with inline discharge (downstream)
 
     In this instance the discharge is downstream of the abstraction, so the
     water shouldn't be available.
-    '''
-    model = load_model('river_discharge2.json')
+    """
+    model = load_model("river_discharge2.json")
     model.step()
-    demand = model.nodes['demand1']
-    term = model.nodes['term1']
+    demand = model.nodes["demand1"]
+    term = model.nodes["term1"]
     assert_allclose(demand.flow, 5.0, atol=1e-7)
     assert_allclose(term.flow, 3.0, atol=1e-7)
 
+
 def test_new_storage():
     """Test new-style storage node with multiple inputs"""
     model = pywr.core.Model(
-        start=pandas.to_datetime('1888-01-01'),
-        end=pandas.to_datetime('1888-01-01'),
-        timestep=datetime.timedelta(1)
+        start=pandas.to_datetime("1888-01-01"),
+        end=pandas.to_datetime("1888-01-01"),
+        timestep=datetime.timedelta(1),
     )
 
-    supply1 = pywr.core.Input(model, 'supply1')
+    supply1 = pywr.core.Input(model, "supply1")
 
-    splitter = pywr.core.Storage(model, 'splitter', outputs=1, inputs=2, max_volume=10, initial_volume=5)
+    splitter = pywr.core.Storage(
+        model, "splitter", outputs=1, inputs=2, max_volume=10, initial_volume=5
+    )
 
-    demand1 = pywr.core.Output(model, 'demand1')
-    demand2 = pywr.core.Output(model, 'demand2')
+    demand1 = pywr.core.Output(model, "demand1")
+    demand2 = pywr.core.Output(model, "demand2")
 
     supply1.connect(splitter)
 
@@ -258,7 +286,7 @@ def test_new_storage():
 
 
 def test_virtual_storage():
-    """ Test the VirtualStorage node """
+    """Test the VirtualStorage node"""
 
     model = pywr.core.Model()
 
@@ -268,7 +296,9 @@ def test_virtual_storage():
     otpt = Output(model, "Output", max_flow=10, cost=-10.0)
     lnk.connect(otpt)
 
-    vs = pywr.core.VirtualStorage(model, "Licence", [lnk], initial_volume=10.0, max_volume=10.0)
+    vs = pywr.core.VirtualStorage(
+        model, "Licence", [lnk], initial_volume=10.0, max_volume=10.0
+    )
 
     model.setup()
 
@@ -286,7 +316,7 @@ def test_virtual_storage():
 
 
 def test_virtual_storage_duplicate_route():
-    """ Test the VirtualStorage node """
+    """Test the VirtualStorage node"""
 
     model = pywr.core.Model()
 
@@ -296,7 +326,14 @@ def test_virtual_storage_duplicate_route():
     otpt = Output(model, "Output", max_flow=10, cost=-10.0)
     lnk.connect(otpt)
 
-    vs = pywr.core.VirtualStorage(model, "Licence", [lnk, otpt], factors=[0.5, 1.0], initial_volume=10.0, max_volume=10.0)
+    vs = pywr.core.VirtualStorage(
+        model,
+        "Licence",
+        [lnk, otpt],
+        factors=[0.5, 1.0],
+        initial_volume=10.0,
+        max_volume=10.0,
+    )
 
     model.setup()
 
@@ -304,7 +341,7 @@ def test_virtual_storage_duplicate_route():
 
     model.step()
 
-    assert_allclose(otpt.flow, [10/1.5], atol=1e-7)
+    assert_allclose(otpt.flow, [10 / 1.5], atol=1e-7)
     assert_allclose(vs.volume, [0], atol=1e-7)
 
     model.step()
@@ -314,16 +351,15 @@ def test_virtual_storage_duplicate_route():
 
 
 class TestRollingVirtualStorage:
-
-    @pytest.mark.parametrize('from_json', [True, False])
+    @pytest.mark.parametrize("from_json", [True, False])
     def test_run(self, from_json):
         """Test RollingVirtualStorage node behaviour."""
 
         if from_json:
-            model = load_model('rolling_virtual_storage.json')
+            model = load_model("rolling_virtual_storage.json")
 
-            vs = model.nodes['Licence']
-            otpt = model.nodes['Output']
+            vs = model.nodes["Licence"]
+            otpt = model.nodes["Output"]
         else:
             model = pywr.core.Model()
 
@@ -333,7 +369,9 @@ class TestRollingVirtualStorage:
             otpt = Output(model, "Output", max_flow=15, cost=-10.0)
             lnk.connect(otpt)
 
-            vs = pywr.core.RollingVirtualStorage(model, "Licence", [lnk], days=3, initial_volume=30.0, max_volume=30.0)
+            vs = pywr.core.RollingVirtualStorage(
+                model, "Licence", [lnk], days=3, initial_volume=30.0, max_volume=30.0
+            )
 
         model.setup()
 
@@ -363,7 +401,7 @@ class TestRollingVirtualStorage:
     def test_run_weekly(self):
         """Test RollingVirtualStorage node behaviour with a weekly timestep."""
 
-        model = pywr.core.Model(timestep='7D')
+        model = pywr.core.Model(timestep="7D")
 
         inpt = Input(model, "Input", max_flow=20)
         lnk = Link(model, "Link")
@@ -371,8 +409,9 @@ class TestRollingVirtualStorage:
         otpt = Output(model, "Output", max_flow=10, cost=-10.0)
         lnk.connect(otpt)
 
-        vs = pywr.core.RollingVirtualStorage(model, "Licence", [lnk], timesteps=3, initial_volume=100.0,
-                                             max_volume=100.0)
+        vs = pywr.core.RollingVirtualStorage(
+            model, "Licence", [lnk], timesteps=3, initial_volume=100.0, max_volume=100.0
+        )
 
         model.setup()
 
@@ -400,23 +439,26 @@ class TestRollingVirtualStorage:
         assert_allclose(vs.volume, [30.0], atol=1e-7)
 
 
-def test_annual_virtual_storage():
-    model = load_model('virtual_storage1.json')
+@pytest.mark.parametrize(
+    "test_model", ["virtual_storage1", "virtual_storage6", "virtual_storage7"]
+)
+def test_annual_virtual_storage(test_model):
+    model = load_model(f"{test_model}.json")
     model.run()
     node = model.nodes["supply1"]
     rec = node.recorders[0]
-    assert_allclose(rec.data[0], 10) # licence is not a constraint
+    assert_allclose(rec.data[0], 10)  # licence is not a constraint
     assert_allclose(rec.data[19], 10)
-    assert_allclose(rec.data[20], 5) # licence is constraint
-    assert_allclose(rec.data[21], 0) # licence is exhausted
-    assert_allclose(rec.data[365], 10) # licence is refreshed
+    assert_allclose(rec.data[20], 5)  # licence is constraint
+    assert_allclose(rec.data[21], 0)  # licence is exhausted
+    assert_allclose(rec.data[365], 10)  # licence is refreshed
 
 
-@pytest.mark.parametrize('reset_to_initial_volume', [None, False, True])
+@pytest.mark.parametrize("reset_to_initial_volume", [None, False, True])
 def test_annual_virtual_storage_reset_to_max_volume(reset_to_initial_volume):
-    """Test that AnnualVirtualStorage resets to maximum volume. """
-    model = load_model('virtual_storage1.json')
-    licence1 = model.nodes['licence1']
+    """Test that AnnualVirtualStorage resets to maximum volume."""
+    model = load_model("virtual_storage1.json")
+    licence1 = model.nodes["licence1"]
     if reset_to_initial_volume is not None:
         licence1.reset_to_initial_volume = reset_to_initial_volume
     licence1.initial_volume = 100
@@ -426,8 +468,7 @@ def test_annual_virtual_storage_reset_to_max_volume(reset_to_initial_volume):
     # After reset the current volume is always the initial volume
     assert_allclose(licence1.volume, [100.0])
 
-
-    model.timestepper.start = '2015-04-01'
+    model.timestepper.start = "2015-04-01"
     model.reset()
     # After stepping over the reset day the volume should have been reset
     # before the solve to either initial volume or maximum volume.
@@ -440,21 +481,26 @@ def test_annual_virtual_storage_reset_to_max_volume(reset_to_initial_volume):
 
 
 def test_annual_virtual_storage_with_dynamic_cost():
-    model = load_model('virtual_storage2.json')
+    model = load_model("virtual_storage2.json")
     model.run()
     node = model.nodes["supply1"]
     rec = node.recorders[0]
 
     assert_allclose(rec.data[0], 10)  # licence is not a constraint
-    assert_allclose(rec.data[1], 5)  # now used slightly too much; switch to the other source
+    assert_allclose(
+        rec.data[1], 5
+    )  # now used slightly too much; switch to the other source
     assert_allclose(rec.data[2], 10)  # continue back and forth.
     assert_allclose(rec.data[3], 5)
 
 
-@pytest.mark.xfail(raises=AssertionError, reason="See issue #1001: https://github.com/pywr/pywr/issues/1001")
+@pytest.mark.xfail(
+    raises=AssertionError,
+    reason="See issue #1001: https://github.com/pywr/pywr/issues/1001",
+)
 def test_annual_virtual_storage_with_piecewise_link():
     """Test `AnnualVirtualStorage` works with `PiecewiseLink`"""
-    model = load_model('virtual_storage3.json')
+    model = load_model("virtual_storage3.json")
     # This should fail before #1001 is fixed properly. Once fixed the assertions about the licence and
     # flow should be uncommented and pass.
     model.run()
@@ -468,10 +514,13 @@ def test_annual_virtual_storage_with_piecewise_link():
     # assert_allclose(rec.data[365], 10) # licence is refreshed
 
 
-@pytest.mark.xfail(raises=AssertionError, reason="See issue #1001: https://github.com/pywr/pywr/issues/1001")
+@pytest.mark.xfail(
+    raises=AssertionError,
+    reason="See issue #1001: https://github.com/pywr/pywr/issues/1001",
+)
 def test_annual_virtual_storage_with_aggregated_node():
     """Test `AnnualVirtualStorage` works with `AggregatedNode`"""
-    model = load_model('virtual_storage4.json')
+    model = load_model("virtual_storage4.json")
     # This should fail before #1001 is fixed properly. Once fixed the assertions about the licence and
     # flow should be uncommented and pass.
     model.run()
@@ -488,7 +537,7 @@ def test_annual_virtual_storage_with_aggregated_node():
 class TestSeasonalVirtualStorage:
     def test_run(self):
 
-        model = load_model('seasonal_virtual_storage.json')
+        model = load_model("seasonal_virtual_storage.json")
         model.run()
         supply_df = model.recorders["supply1"].to_dataframe()
         licence_df = model.recorders["licence1"].to_dataframe()
@@ -516,7 +565,7 @@ class TestSeasonalVirtualStorage:
         means that the node's active period extends from one year to the next
         """
 
-        model = load_model('seasonal_virtual_storage.json')
+        model = load_model("seasonal_virtual_storage.json")
 
         vs = model.nodes["licence1"]
         vs.reset_day = 1
@@ -546,10 +595,9 @@ class TestSeasonalVirtualStorage:
         assert_allclose(licence_df.loc["2016-12-01", :], 90)
 
     def test_start_deactivated(self):
-        """test the the node is not active when:  model start date < reset date < end date
-        """
+        """test the the node is not active when:  model start date < reset date < end date"""
 
-        model = load_model('seasonal_virtual_storage.json')
+        model = load_model("seasonal_virtual_storage.json")
 
         vs = model.nodes["licence1"]
         vs.reset_day = 1
@@ -591,8 +639,12 @@ def test_storage_spill_compensation():
     """
     model = pywr.core.Model()
 
-    catchment = pywr.core.Input(model, name="Input", min_flow=10.0, max_flow=10.0, cost=1)
-    reservoir = pywr.core.Storage(model, name="Storage", max_volume=100, initial_volume=100.0)
+    catchment = pywr.core.Input(
+        model, name="Input", min_flow=10.0, max_flow=10.0, cost=1
+    )
+    reservoir = pywr.core.Storage(
+        model, name="Storage", max_volume=100, initial_volume=100.0
+    )
     spill = pywr.core.Link(model, name="Spill", cost=1.0)
     compensation = pywr.core.Link(model, name="Compensation", max_flow=3.0, cost=-999)
     terminator = pywr.core.Output(model, name="Terminator", cost=-1.0)
@@ -611,7 +663,9 @@ def test_storage_spill_compensation():
     assert_allclose(demand.flow[0], 5.0, atol=1e-7)
     assert_allclose(compensation.flow[0], 3.0, atol=1e-7)
     assert_allclose(spill.flow[0], 2.0, atol=1e-7)
-    assert_allclose(terminator.flow[0], (compensation.flow[0] + spill.flow[0]), atol=1e-7)
+    assert_allclose(
+        terminator.flow[0], (compensation.flow[0] + spill.flow[0]), atol=1e-7
+    )
 
 
 def test_reservoir_circle():
@@ -699,7 +753,7 @@ def test_reservoir_circle():
 
 
 def test_breaklink_node():
-    model = load_model('breaklink.json')
+    model = load_model("breaklink.json")
     supply = model.nodes["A"]
     transfer = model.nodes["B"]
     demand = model.nodes["C"]
@@ -711,10 +765,10 @@ def test_breaklink_node():
     assert_allclose(transfer.storage.volume, 0)
 
 
-@pytest.mark.parametrize('loss_factor', [None, 0.2, 0.99, 1.0, 0.0])
+@pytest.mark.parametrize("loss_factor", [None, 0.2, 0.99, 1.0, 0.0])
 def test_loss_link_node(loss_factor):
     """Test LossLink node"""
-    model = load_model('loss_link.json')
+    model = load_model("loss_link.json")
 
     supply1 = model.nodes["supply1"]
     link1 = model.nodes["link1"]
@@ -746,7 +800,8 @@ def test_loss_link_node(loss_factor):
 
 def test_reservoir_surface_area():
     from pywr.parameters import InterpolatedVolumeParameter
-    model = load_model('reservoir_evaporation.json')
+
+    model = load_model("reservoir_evaporation.json")
     model.timestepper.start = "1920-01-01"
     model.timestepper.end = "1920-01-02"
     res = model.run()
@@ -756,24 +811,24 @@ def test_reservoir_surface_area():
 
 
 def test_reservoir_surface_area_without_area_property():
-    """ Temporary test while the above test is not working. """
-    model = load_model('reservoir_evaporation_without_area_property.json')
+    """Temporary test while the above test is not working."""
+    model = load_model("reservoir_evaporation_without_area_property.json")
     model.timestepper.start = "1920-01-01"
     model.timestepper.end = "1920-01-02"
     res = model.run()
     assert_allclose(model.nodes["evaporation"].flow, 2.46875)
 
+
 def test_reservoir_surface_area_external_data():
-    """ Testing the InterpolatedVolume parameter with external data as
-    inputs of Volume and Values, in this case a .csv file. """
-    model = load_model('reservoir_evaporation_areafromfile.json')
+    """Testing the InterpolatedVolume parameter with external data as
+    inputs of Volume and Values, in this case a .csv file."""
+    model = load_model("reservoir_evaporation_areafromfile.json")
     model.timestepper.start = "1920-01-01"
     model.timestepper.end = "1920-01-02"
     res = model.run()
     assert_allclose(model.nodes["evaporation"].flow, 2.46875)
 
 
-
 def test_run_empty():
     # empty model should raise an exception if run
     model = Model()
@@ -782,26 +837,26 @@ def test_run_empty():
 
 
 def test_run():
-    model = load_model('simple1.json')
+    model = load_model("simple1.json")
 
     # run model from start to finish
     result = model.run()
-    assert(result.timestep.index == 364)
+    assert result.timestep.index == 364
 
     # reset model and run again
     result = model.run()
-    assert(result.timestep.index == 364)
+    assert result.timestep.index == 364
 
     # run remaining timesteps
-    model.reset(start=pandas.to_datetime('2015-12-01'))
+    model.reset(start=pandas.to_datetime("2015-12-01"))
     result = model.run()
-    assert(result.timestep.index == 364)
+    assert result.timestep.index == 364
 
 
 def test_reset_prev_flow():
     """Test resetting the prev_flow attribte of a node."""
-    model = load_model('simple1.json')
-    demand1 = model.nodes['demand1']
+    model = load_model("simple1.json")
+    demand1 = model.nodes["demand1"]
     model.run()
     assert_allclose(demand1.flow, 10.0, atol=1e-7)
     assert_allclose(demand1.prev_flow, 10.0, atol=1e-7)
@@ -816,7 +871,7 @@ def test_reset_prev_flow():
 
 
 def test_run_monthly():
-    model = load_model('simple1_monthly.json')
+    model = load_model("simple1_monthly.json")
 
     result = model.run()
     assert result.timestep.index == 11
@@ -829,24 +884,35 @@ def test_select_solver():
     """Test specifying the solver in JSON"""
     solver_names = [solver.name for solver in pywr.solvers.solver_registry]
     for solver_name in solver_names:
-        data = '''{"metadata": {"minimum_version": "0.1"}, "nodes": {}, "edges": {}, "timestepper": {"start": "1990-01-01","end": "1999-12-31","timestep": 1}, "solver": {"name": "%s"}}''' % solver_name
+        data = (
+            """{"metadata": {"minimum_version": "0.1"}, "nodes": {}, "edges": {}, "timestepper": {"start": "1990-01-01","end": "1999-12-31","timestep": 1}, "solver": {"name": "%s"}}"""
+            % solver_name
+        )
         model = load_model(data=data)
-        assert(model.solver.name.lower() == solver_name)
+        assert model.solver.name.lower() == solver_name
+
 
 def test_solver_unrecognised():
-    '''Test specifying an unrecognised solver JSON'''
-    solver_name = 'foobar'
-    data = '''{"metadata": {"minimum_version": "0.1"}, "nodes": {}, "edges": {}, "timestepper": {"start": "1990-01-01","end": "1999-12-31","timestep": 1}, "solver": {"name": "%s"}}''' % solver_name
+    """Test specifying an unrecognised solver JSON"""
+    solver_name = "foobar"
+    data = (
+        """{"metadata": {"minimum_version": "0.1"}, "nodes": {}, "edges": {}, "timestepper": {"start": "1990-01-01","end": "1999-12-31","timestep": 1}, "solver": {"name": "%s"}}"""
+        % solver_name
+    )
     with pytest.raises(KeyError):
         model = load_model(data=data)
 
+
 @pytest.mark.skipif(Model().solver.name != "glpk", reason="only valid for glpk")
 @pytest.mark.parametrize("use_presolve", ["true", "false"])
 def test_select_glpk_presolve(use_presolve):
     """Test specifying the solver in JSON"""
     solver_names = ["glpk"]
     for solver_name in solver_names:
-        data = '''{"metadata": {"minimum_version": "0.1"}, "nodes": {}, "edges": {}, "timestepper": {"start": "1990-01-01","end": "1999-12-31","timestep": 1}, "solver": {"name": "%s", "use_presolve": %s}}''' % (solver_name, use_presolve)
+        data = (
+            """{"metadata": {"minimum_version": "0.1"}, "nodes": {}, "edges": {}, "timestepper": {"start": "1990-01-01","end": "1999-12-31","timestep": 1}, "solver": {"name": "%s", "use_presolve": %s}}"""
+            % (solver_name, use_presolve)
+        )
         model = load_model(data=data)
-        assert(model.solver.name.lower() == solver_name)
-        assert(model.solver._cy_solver.use_presolve == (use_presolve == "true"))
+        assert model.solver.name.lower() == solver_name
+        assert model.solver._cy_solver.use_presolve == (use_presolve == "true")
